==> eff-list_3-7.0.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"list","t":"list","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax.html#","e":false,"i":"","n":"org.atnos.eff.syntax","t":"org.atnos.eff.syntax","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/list$.html#","e":false,"i":"","n":"list","t":"list extends list","d":"org.atnos.eff.syntax","k":"object","x":""},
{"l":"org/atnos/eff/syntax/list.html#","e":false,"i":"","n":"list","t":"list","d":"org.atnos.eff.syntax","k":"trait","x":""},
{"l":"org/atnos/eff/syntax/list.html#ListEffectOps-56b","e":false,"i":"","n":"ListEffectOps","t":"ListEffectOps[R, A](e: Eff[R, A]): ListEffectOps[R, A]","d":"org.atnos.eff.syntax.list","k":"def","x":""},
{"l":"org/atnos/eff/syntax/list$ListEffectOps.html#","e":false,"i":"","n":"ListEffectOps","t":"ListEffectOps[R, A](e: Eff[R, A])","d":"org.atnos.eff.syntax.list","k":"class","x":""},
{"l":"org/atnos/eff/syntax/list$ListEffectOps.html#runList-8c7","e":false,"i":"","n":"runList","t":"runList(implicit member: Member[List, R]): Eff[Out, List[A]]","d":"org.atnos.eff.syntax.list.ListEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation.html#","e":false,"i":"","n":"ListCreation","t":"ListCreation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/ListCreation.html#_List-0","e":false,"i":"","n":"_List","t":"_List[R] = Member[List, R]","d":"org.atnos.eff.ListCreation","k":"type","x":""},
{"l":"org/atnos/eff/ListCreation.html#_list-0","e":false,"i":"","n":"_list","t":"_list[R] = MemberIn[List, R]","d":"org.atnos.eff.ListCreation","k":"type","x":""},
{"l":"org/atnos/eff/ListCreation.html#empty-cb0","e":false,"i":"","n":"empty","t":"empty[R : _list, A]: Eff[R, A]","d":"org.atnos.eff.ListCreation","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation.html#fromList-ffffff42","e":false,"i":"","n":"fromList","t":"fromList[R : _list, A](as: List[A]): Eff[R, A]","d":"org.atnos.eff.ListCreation","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation.html#singleton-7bd","e":false,"i":"","n":"singleton","t":"singleton[R : _list, A](a: A): Eff[R, A]","d":"org.atnos.eff.ListCreation","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation.html#values-fffffba5","e":false,"i":"","n":"values","t":"values[R : _list, A](as: A*): Eff[R, A]","d":"org.atnos.eff.ListCreation","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation$.html#","e":false,"i":"","n":"ListCreation","t":"ListCreation extends ListCreation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/ListEffect.html#","e":false,"i":"","n":"ListEffect","t":"ListEffect extends ListCreation, ListInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/ListEffect$.html#","e":false,"i":"","n":"ListEffect","t":"ListEffect extends ListEffect","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/ListInterpretation.html#","e":false,"i":"","n":"ListInterpretation","t":"ListInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/ListInterpretation.html#runList-b17","e":false,"i":"","n":"runList","t":"runList[R, U, A](effect: Eff[R, A])(implicit m: Aux[List, R, U]): Eff[U, List[A]]","d":"org.atnos.eff.ListInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/ListInterpretation$.html#","e":false,"i":"","n":"ListInterpretation","t":"ListInterpretation extends ListInterpretation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/list$.html#","e":false,"i":"","n":"list","t":"list extends ListCreation, ListInterpretation","d":"org.atnos.eff","k":"object","x":""}];

==> eff-list_3-7.0.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"list","t":"list","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax.html#","e":false,"i":"","n":"org.atnos.eff.syntax","t":"org.atnos.eff.syntax","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/list$.html#","e":false,"i":"","n":"list","t":"list extends list","d":"org.atnos.eff.syntax","k":"object","x":""},
{"l":"org/atnos/eff/syntax/list.html#","e":false,"i":"","n":"list","t":"list","d":"org.atnos.eff.syntax","k":"trait","x":""},
{"l":"org/atnos/eff/syntax/list.html#ListEffectOps-56b","e":false,"i":"","n":"ListEffectOps","t":"ListEffectOps[R, A](e: Eff[R, A]): ListEffectOps[R, A]","d":"org.atnos.eff.syntax.list","k":"def","x":""},
{"l":"org/atnos/eff/syntax/list$ListEffectOps.html#","e":false,"i":"","n":"ListEffectOps","t":"ListEffectOps[R, A](e: Eff[R, A])","d":"org.atnos.eff.syntax.list","k":"class","x":""},
{"l":"org/atnos/eff/syntax/list$ListEffectOps.html#runList-8c7","e":false,"i":"","n":"runList","t":"runList(implicit member: Member[List, R]): Eff[member.Out, List[A]]","d":"org.atnos.eff.syntax.list.ListEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation.html#","e":false,"i":"","n":"ListCreation","t":"ListCreation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/ListCreation.html#_List-0","e":false,"i":"","n":"_List","t":"_List[R] = Member[List, R]","d":"org.atnos.eff.ListCreation","k":"type","x":""},
{"l":"org/atnos/eff/ListCreation.html#_list-0","e":false,"i":"","n":"_list","t":"_list[R] = MemberIn[List, R]","d":"org.atnos.eff.ListCreation","k":"type","x":""},
{"l":"org/atnos/eff/ListCreation.html#empty-cb0","e":false,"i":"","n":"empty","t":"empty[R : _list, A]: Eff[R, A]","d":"org.atnos.eff.ListCreation","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation.html#fromList-ffffff42","e":false,"i":"","n":"fromList","t":"fromList[R : _list, A](as: List[A]): Eff[R, A]","d":"org.atnos.eff.ListCreation","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation.html#singleton-7bd","e":false,"i":"","n":"singleton","t":"singleton[R : _list, A](a: A): Eff[R, A]","d":"org.atnos.eff.ListCreation","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation.html#values-fffffba5","e":false,"i":"","n":"values","t":"values[R : _list, A](as: A*): Eff[R, A]","d":"org.atnos.eff.ListCreation","k":"def","x":""},
{"l":"org/atnos/eff/ListCreation$.html#","e":false,"i":"","n":"ListCreation","t":"ListCreation extends ListCreation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/ListEffect.html#","e":false,"i":"","n":"ListEffect","t":"ListEffect extends ListCreation, ListInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/ListEffect$.html#","e":false,"i":"","n":"ListEffect","t":"ListEffect extends ListEffect","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/ListInterpretation.html#","e":false,"i":"","n":"ListInterpretation","t":"ListInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/ListInterpretation.html#runList-b17","e":false,"i":"","n":"runList","t":"runList[R, U, A](effect: Eff[R, A])(implicit m: Aux[List, R, U]): Eff[U, List[A]]","d":"org.atnos.eff.ListInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/ListInterpretation$.html#","e":false,"i":"","n":"ListInterpretation","t":"ListInterpretation extends ListInterpretation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/list$.html#","e":false,"i":"","n":"list","t":"list extends ListCreation, ListInterpretation","d":"org.atnos.eff","k":"object","x":""}];
